@@ -63,28 +63,54 @@ TrueGallery = function(element, options){
     */
     tg.effects = {
         fade: {
-            hide: function(truegallery, image, cb){
+            hide: function(image, nextImage, cb){
+                jq(tg.selectors.galleryViewSelector).height(nextImage.height());
                 return image.fadeOut(tg.options.hideSpeed, cb);
             },
-            show: function(truegallery, image, cb){
+            show: function(image, previousImage, cb){
                 return image.fadeIn(tg.options.showSpeed, cb);
             }
         },
         slide: {
-            hide: function(truegallery, image, cb){
+            hide: function(image, nextImage, cb){
+                jq(tg.selectors.galleryViewSelector).height(nextImage.height());
                 return image.slideUp(tg.options.hideSpeed, cb);
             },
-            show: function(truegallery, image, cb){
+            show: function(image, previousImage, cb){
                 return image.slideDown(tg.options.showSpeed, cb);
             }
         },
         show: {
-            hide: function(truegallery, image, cb){
+            hide: function(image, nextImage, cb){
+                jq(tg.selectors.galleryViewSelector).height(nextImage.height());
                 return image.hide(tg.options.hideSpeed, cb);
             },
-            show: function(truegallery, image, cb){
+            show: function(image, previousImage, cb){
                 return image.show(tg.options.showSpeed, cb);
             }
+        },
+        animate: {
+            hide: function(image, nextImage, cb){
+                jq(tg.selectors.galleryViewSelector).height(nextImage.height());
+                return image.animate({
+                    width: '0px',
+                    height: '0px',
+                    opacity: 0.0
+                }, tg.options.hideSpeed, cb);
+            },
+            show: function(image, previousImage, cb){
+                var prevWidth = image.width();
+                var prevHeight = image.height();
+                image.width(0);
+                image.height(0);
+                image.show();
+                image.css('opacity', 0.0);
+                return image.animate({
+                    width: prevWidth + 'px',
+                    height: prevHeight + 'px',
+                    opacity: 1.0
+                }, tg.options.showSpeed, cb);
+            }
         }
     };
     
@@ -138,7 +164,9 @@ TrueGallery = function(element, options){
                 break;
             }
         }
-        jq(tg.selectors.titleSelector).html(containerImage.find('h2').html() + " (" + (selectedIndex+1) + "/" + images.size() + ")");
+        var numberOfImages = kukit.dom.getKssAttribute(jq('div#plone-true-gallery')[0], 'numberOfImages');
+        
+        jq(tg.selectors.titleSelector).html(containerImage.find('h2').html() + " (" + (selectedIndex+1) + "/" + numberOfImages + ")");
         jq(tg.selectors.descriptionSelector).html(containerImage.find('p').html());
         jq(tg.selectors.linkSelector).attr('href', kukit.dom.getKssAttribute(containerImage[0], 'link'));
     };
@@ -247,12 +275,12 @@ TrueGallery = function(element, options){
         tg.triggerLoadMoreImages();
     };
     
-    tg.hide = function(image, cb){
-        return tg.effects[tg.options.hideType].hide(tg, image, cb);
+    tg.hide = function(image, nextImage, cb){
+        return tg.effects[tg.options.hideType].hide(image, nextImage, cb);
     };
     
-    tg.show = function(image, cb){
-        return tg.effects[tg.options.hideType].show(tg, image, cb);
+    tg.show = function(image, previousImage, cb){
+        return tg.effects[tg.options.showType].show(image, previousImage, cb);
     };
     
     tg.getCarouselPos = function(image){
@@ -279,10 +307,10 @@ TrueGallery = function(element, options){
         
         if(newImage[0] != currentImage[0] && !tg.toggling){
             tg.toggling = true;
-            tg.hide(currentImage.find('img'), function(){
+            tg.hide(currentImage.find('img'), newImage.find('img'), function(){
                 currentImage.removeClass('selected');                 
                 
-                tg.show(newImage.find('img'), function(){
+                tg.show(newImage.find('img'), currentImage.find('img'), function(){
                     tg.setNewCarouselPosition(tg.getCarouselPos(newImage));
                     newImage.addClass('selected');
                     tg.setInfo();
