@@ -85,6 +85,10 @@ class BasicGallery:
                 if self._image_sizes[size][0] > self._image_sizes[self._gallery.image_size][0]:
                     self._gallery.image_size = size
             
+    def numberOfImages(self):
+        images = [i for i in self._gallery.objectIds() if self._gallery[i].meta_type == "ATImage"]
+        return len(images)
+        
     def getFirstImage(self):
         ids = self._gallery.objectIds()
         
