@@ -79,40 +79,32 @@ schema = Schema((
         required=1,
         default=500
     ),
+    StringField(
+        name="inTransition",
+        widget=SelectionWidget(
+            label="Fade In Transition",
+            description="Select the transition you want to use when an image is being added."
+        ),
+        vocabulary=TRANSITIONS,
+        default="fade",
+        enforceVocabulary = True
+    ),
     IntegerField(
         name='fadeOutDuration',
         widget=IntegerField._properties['widget'](
-            label="Fade out Duration",
+            label="Fade Out Duration",
             description="The amount of time the fading effect should take in miliseconds."
         ),
         required=1,
         default=500
     ),
-    StringField(
-        name="inTransition",
-        widget=SelectionWidget(
-            label="Transition",
-            description="Select the transition you want to use when an image is being added."
-        ),
-        vocabulary=(
-            ('fade', 'Fade'),
-            ('slide', 'Slide'),
-            ('show', 'Show')
-        ),
-        default="fade",
-        enforceVocabulary = True
-    ),
     StringField(
         name="outTransition",
         widget=SelectionWidget(
-            label="Transition Out",
+            label="Fade Out Transition",
             description="Select the transition you want to use when an image is being removed."
         ),
-        vocabulary=(
-            ('fade', 'Fade'),
-            ('slide', 'Slide'),
-            ('show', 'Show')
-        ),
+        vocabulary=TRANSITIONS,
         default="fade",
         enforceVocabulary = True
     ),
@@ -221,6 +213,9 @@ class Gallery(ATFolder):
     def info(self):
         return self.getGalleryType().info()
     
+    def numberOfImages(self):
+        return self.getGalleryType().numberOfImages()
+    
     def generateJavascript(self):
         return """
         jq(document).ready(function(){
